@@ -38,7 +38,7 @@ from mlflow.utils.mlflow_tags import (
     MLFLOW_RUN_NAME,
     MLFLOW_RUN_NOTE,
 )
-from mlflow.utils.validation import _validate_run_id
+from mlflow.utils.validation import _validate_run_id, _validate_experiment_id_type
 
 if TYPE_CHECKING:
     import pandas  # pylint: disable=unused-import
@@ -80,11 +80,10 @@ def set_experiment(experiment_name: str = None, experiment_id: str = None) -> Ex
 
         import mlflow
 
-        # Set an experiment name, which must be unique and case sensitive.
-        mlflow.set_experiment("Social NLP Experiments")
+        # Set an experiment name, which must be unique and case-sensitive.
+        experiment = mlflow.set_experiment("Social NLP Experiments")
 
         # Get Experiment Details
-        experiment = mlflow.get_experiment_by_name("Social NLP Experiments")
         print("Experiment_id: {}".format(experiment.experiment_id))
         print("Artifact Location: {}".format(experiment.artifact_location))
         print("Tags: {}".format(experiment.tags))
@@ -130,9 +129,9 @@ def set_experiment(experiment_name: str = None, experiment_id: str = None) -> Ex
     if experiment.lifecycle_stage != LifecycleStage.ACTIVE:
         raise MlflowException(
             message=(
-                "Cannot set a deleted experiment '%s' as the active experiment."
-                " You can restore the experiment, or permanently delete the "
-                " experiment to create a new one." % experiment.name
+                "Cannot set a deleted experiment '%s' as the active experiment. "
+                "You can restore the experiment, or permanently delete the "
+                "experiment to create a new one." % experiment.name
             ),
             error_code=INVALID_PARAMETER_VALUE,
         )
@@ -231,6 +230,7 @@ def start_run(
         0  78b3b0d264b44cd29e8dc389749bb4be          yes           CHILD_RUN
     """
     global _active_run_stack
+    _validate_experiment_id_type(experiment_id)
     # back compat for int experiment_id
     experiment_id = str(experiment_id) if isinstance(experiment_id, int) else experiment_id
     if len(_active_run_stack) > 0 and not nested:
@@ -1203,7 +1203,7 @@ def search_runs(
         print("--")
 
         # Search for all the runs in the experiment with the given experiment name
-        df = mlflow.search_runs(experiment_name=[experiment_name], order_by=["metrics.m DESC"])
+        df = mlflow.search_runs(experiment_names=[experiment_name], order_by=["metrics.m DESC"])
         print(df[["metrics.m", "tags.s.release", "run_id"]])
 
 
